@@ -103,12 +103,21 @@ class CreateBookInput(MutationSchema):
                     "namespace": "book",
                     "value": self.published_date,
                 },
+                {
+                    "key": "isbn",
+                    "namespace": "facts",
+                    "value": self.isbn,
+                },
                 {
                     "key": "staff_comment",
                     "namespace": "book",
                     "value": self.staff_comment,
                 },
-                {"key": "backorder", "namespace": "book", "value": self.is_backorder},
+                {
+                    "key": "backorder",
+                    "namespace": "book",
+                    "value": "true" if self.is_backorder else "false",
+                },
             ],
         }
         if self.cover_image:
